@@ -26,7 +26,7 @@ Options:
 from __future__ import absolute_import
 from docopt import docopt
 from pylog.pylog import init_logger
-from pylog.pylog import set_global_verbosity_level
+from pylog.pylog import _set_global_verbosity_level
 from pylog.pylog import generator, list_fake_types
 
 lgr = init_logger()
