@@ -306,7 +306,7 @@ def list_fake_types():
     # to implement this...
     # list from fake-factory
     for fake_type in dir(fake):
-        if not fake_type.startswith('_') and not fake_type in ignore_list:
+        if not fake_type.startswith('_') and fake_type not in ignore_list:
             fakes_list.append('*** {} ({})'.format(
                 fake_type, getattr(fake, fake_type)()))
     # list from format mappings default handler
@@ -317,7 +317,6 @@ def list_fake_types():
         if not fake_type.startswith('_') and not fake_type == 'default':
             fakes_list.append('*** {} ({})'.format(
                 fake_type, getattr(fm.InHouseFaker(), fake_type)()))
-
     print("\n".join(fakes_list))
 
 
